% setdefault('cfgfile', None)
% setdefault('cfg', None)
% setdefault('user', None)
% rebase('tpl/base.html', title = 'home')
<p>
	User: {{user}}
	<br>
	Config file: {{cfgfile}}
</p>
<hr>
<p>
% for line in cfg.splitlines():
	{{line}}<br>
% end
</p>
