% setdefault('profiles', [])
% rebase('tpl/base.html', title = 'profile')
<hr>
% for prof in profiles:
<ul class="w3-bar">
	<li class="w3-bar-item">{{prof.get('name', 'no name')}}</li>
	<li class="w3-bar-item">
	% for env in prof.get('envs', []):
		{{env}}<br>
	% end
	</li>
</ul>
<hr>
% end
