% setdefault('sidebar', [])
% setdefault('title', '')
% itemClass = 'w3-bar-item w3-button'
% itemColorClass = 'w3-hover-grey'
% curColorClass = 'sadm-bgcolor w3-hover-grey'
% for item in sidebar:
<%
	colorClass = itemColorClass
	if item['desc'] == title:
		colorClass = curColorClass
	end
%>
	<a href="{{item['href']}}"
		class="{{itemClass}} {{colorClass}}">{{item['desc']}}</a>
% end
