% setdefault('title', 'no title')
% setdefault('sidebar', [])
% sidebarWidth = '8%'
<!DOCTYPE html>
<html>
	<head>
		<title>sadm/{{title}}</title>
		<meta charset="UTF-8">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="shortcut icon" href="/static/favicon.ico">
		<link rel="stylesheet" href="/static/lib/w3.css">
		<link rel="stylesheet" href="/static/css/sadm.css">
	</head>
	<body class="w3-dark-grey w3-text-black">
		<!-- sidebar -->
		<div class="w3-sidebar w3-bar-block w3-large w3-black w3-text-grey"
			style="width:{{sidebarWidth}};min-width:55px">
			% include('tpl/sidebar.html', sidebar = sidebar)
		</div>
		<!-- end of sidebar -->
		<!-- main container -->
		<div class="w3-container" style="margin-left:{{sidebarWidth}}">
			<div id="top" class="w3-margin-top"></div>
			<!-- main content -->
			<div class="w3-container sadm-bgcolor sadm-color">
				{{!base}}
			</div>
			<!-- end of main content -->
			<footer>
				<p class="w3-small">
					sadm version {{version}}
					view:{{view}}
					took:{{took}}s
					<br>
					{{now}}
				</p>
			</footer>
		</div>
		<!-- end of main container -->
	</body>
</html>
