% setdefault('sidebar', [])
% setdefault('title', '')
<%
sidebarPre = [
	{'desc': 'home', 'href': '/'},
	{'desc': 'profile', 'href': '/profile'},
]
sidebarPost = [
	{'desc': 'syslog', 'href': '/syslog#end'},
	{'desc': 'about', 'href': '/about'},
]
%>
<!-- sidebar pre -->
% include('tpl/sidebar-items.html', title = title, sidebar = sidebarPre)
<!-- end of sidebar pre -->
<!-- sidebar items -->
% include('tpl/sidebar-items.html', title = title, sidebar = sidebar)
<!-- end of sidebar items -->
<!-- sidebar post -->
% include('tpl/sidebar-items.html', title = title, sidebar = sidebarPost)
<!-- end of sidebar post -->
