% setdefault('err', None)
<!DOCTYPE html>
<html>
	<head>
		<title>sadm/error</title>
		<meta charset="UTF-8">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="shortcut icon" href="/static/favicon.ico">
		<link rel="stylesheet" href="/static/lib/w3.css">
		<link rel="stylesheet" href="/static/css/sadm.css">
	</head>
	<body class="w3-dark-grey w3-text-black">
		<div class="w3-container w3-margin-top">
			<h2 class="w3-red w3-padding">
				{{err.status_line}}
				% if err.exception:
				<br>
				{{err.exception}}
				% end
			</h2>
		</div>
		<footer class="w3-margin-left">
			<p class="w3-small">
				sadm version {{version}}
				view:{{view}}
				took:{{took}}s
				<br>
				{{now}}
			</p>
		</footer>
	</body>
</html>

