body {
	margin: 0;
	padding: 0;
	background-color: #111;
}
body, h1, h2, h3, h4, h5, h6 {
	font-family: monospace;
	font-size: 1em;
}
h6 {
	font-size: 1.15em;
}
h5 {
	font-size: 1.30em;
}
h4 {
	font-size: 1.45em;
}
h3 {
	font-size: 1.60em;
}
h2 {
	font-size: 1.75em;
}
h1 {
	font-size: 1.9em;
}
hr {
	border: 0.5px solid #333;
}
.w3-btn {
	color: #000;
	background-color: #9e9e9e;
}
.w3-btn:hover {
	color: #9e9e9e;
	background-color: #000;
}
.sadm-color {
	color: #ccc;
}
.sadm-bgcolor {
	background-color: #111;
}
.syslog-default {
	color: #0cc;
}
.syslog-error {
	color: #c00;
}
.syslog-warn {
	color: #cc0;
}
.syslog-info {
	color: #00c;
}
.syslog-msg {
	color: #0c0;
}
